import { describe, it, expect } from 'vitest'
import { build } from 'vite'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle } from '../util'

const __dirname = import.meta.dirname

describe('Preload helper separate', () => {
  it('replaces code for relative path loading', async () => {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        minify: false,
        write: false,
        rollupOptions: {
          input: {}
        }
      },
      plugins: [vitePluginOxManifests({
        entryPoints: [`${__dirname}/{foo,bar}.js`]
      })]
    })

    const preloadHelper = getFileFromBundle('preload', bundle)
    expect(preloadHelper.code).toContain('const __vitePreload = function preload')

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(4)
    expect(manifests['index.js'].imports).toHaveLength(1)
    expect(manifests['index.js'].imports[0]).toContain('preload-helper')
  })
})
